@@ -97,7 +97,7 @@ dlg_ask_password__common (FrWindow       *window,
 
 	data = g_new0 (DialogData, 1);
 
-	data->builder = _gtk_builder_new_from_file ("batch-password.ui");
+	data->builder = _gtk_builder_new_from_resource ("batch-password.ui");
 	if (data->builder == NULL) {
 		g_free (data);
 		return;
