@@ -259,7 +259,7 @@ file_sel_response_cb (GtkWidget    *widget,
 	}
 
 	if (response == GTK_RESPONSE_HELP) {
-		show_help_dialog (GTK_WINDOW (data->dialog), "file-roller-extract-options");
+		show_help_dialog (GTK_WINDOW (data->dialog), "archive-extract");
 		return TRUE;
 	}
 
