@@ -24,6 +24,7 @@
 #include "gtk-utils.h"
 
 #define LOAD_BUFFER_SIZE 65536
+#define FILE_ROLLER_RESOURCE_UI_PATH "/org/gnome/FileRoller/ui/"
 
 
 static void
@@ -740,7 +741,7 @@ show_help_dialog (GtkWindow  *parent,
 	char   *uri;
 	GError *error = NULL;
 
-	uri = g_strconcat ("ghelp:file-roller", section ? "?" : NULL, section, NULL);
+	uri = g_strconcat ("help:file-roller", section ? "?" : NULL, section, NULL);
 	if (! show_uri (gtk_window_get_screen (parent), uri, GDK_CURRENT_TIME, &error)) {
   		GtkWidget *dialog;
 
@@ -786,6 +787,25 @@ _gtk_builder_new_from_file (const char *ui_file)
 }
 
 
+GtkBuilder *
+_gtk_builder_new_from_resource (const char *resource_path)
+{
+	GtkBuilder *builder;
+	char       *full_path;
+	GError     *error = NULL;
+
+	builder = gtk_builder_new ();
+	full_path = g_strconcat (FILE_ROLLER_RESOURCE_UI_PATH, resource_path, NULL);
+        if (! gtk_builder_add_from_resource (builder, full_path, &error)) {
+                g_warning ("%s\n", error->message);
+                g_clear_error (&error);
+        }
+	g_free (full_path);
+
+        return builder;
+}
+
+
 GtkWidget *
 _gtk_builder_get_widget (GtkBuilder *builder,
 			 const char *name)
