@@ -83,6 +83,8 @@ void        show_help_dialog                (GtkWindow    *parent,
 					     const char   *section);
 GtkBuilder *  
             _gtk_builder_new_from_file      (const char   *filename);
+GtkBuilder *
+	   _gtk_builder_new_from_resource   (const char   *resource_path);
 GtkWidget *
 	    _gtk_builder_get_widget         (GtkBuilder   *builder,
 			 		     const char   *name);
